aboutsummaryrefslogtreecommitdiff
path: root/run_response.go
diff options
context:
space:
mode:
Diffstat (limited to 'run_response.go')
-rw-r--r--run_response.go12
1 files changed, 6 insertions, 6 deletions
diff --git a/run_response.go b/run_response.go
index 9df7671..0586c6e 100644
--- a/run_response.go
+++ b/run_response.go
@@ -25,20 +25,20 @@ type RunResponse struct {
ResponseStatusCode int
}
// SetHttpRequest dump the HTTP request including body into the DumpRequest
// field.
-func (rres *RunResponse) SetHttpRequest(req *http.Request) (err error) {
+func (rres *RunResponse) SetHTTPRequest(req *http.Request) (err error) {
rres.DumpRequest, err = httputil.DumpRequest(req, true)
if err != nil {
- return fmt.Errorf("SetHttpRequest: %w", err)
+ return fmt.Errorf(`SetHTTPRequest: %w`, err)
}
return nil
}
// SetHttpResponse dump the HTTP response including body into the DumpResponse
// field.
-func (rres *RunResponse) SetHttpResponse(res *http.Response) (err error) {
- logp := "SetHttpResponse"
+func (rres *RunResponse) SetHTTPResponse(res *http.Response) (err error) {
+ var logp = `SetHTTPResponse`
rres.ResponseStatus = res.Status
rres.ResponseStatusCode = res.StatusCode
@@ -25,20 +25,20 @@ type RunResponse struct {
ResponseStatusCode int
}
-// SetHttpRequest dump the HTTP request including body into the DumpRequest
+// SetHTTPRequest dump the HTTP request including body into the DumpRequest
// field.
@@ -25,20 +25,20 @@ type RunResponse struct {
return nil
}
-// SetHttpResponse dump the HTTP response including body into the DumpResponse
+// SetHTTPResponse dump the HTTP response including body into the DumpResponse
// field.